@@ -1,11 +1,12 @@
 
 import unittest
 from math import exp, sqrt
+from datetime import datetime, timedelta
 
 import numpy as np
 
+from finsim.estimate.fit import fit_BlackScholesMerton_model
 from finsim.simulation.stock import BlackScholesMertonStockPrices, HestonStockPrices, MertonJumpDiffusionStockPrices
-from finsim.estimate.fit import fortranfit
 
 
 def expected_bsm_stock(S0, r, sigma, t):
@@ -16,11 +17,15 @@ def expected_bsm_stock(S0, r, sigma, t):
 
 class TestStockSimulations(unittest.TestCase):
     def backend_test_BlackScholesMertonStocks(self, S, r, sigma, T, dt, nbsimulations):
-        ts = np.linspace(0, T, int(T // dt) + 1)
+        numerical_ts = np.linspace(0, T, int(T // dt) + 1)
+        ts = np.array([
+            datetime(2020, 1, 1, 0, 0, 0) + timedelta(days=numerical_ts[i])
+            for i in range(len(numerical_ts))
+        ], dtype='datetime64[s]')
 
         bsm_simulator = BlackScholesMertonStockPrices(S, r, sigma)
         sarray = bsm_simulator.generate_time_series(T, dt, nbsimulations=nbsimulations)
-        rsigma_array = np.array([fortranfit.f90_fit_blackscholesmerton_model(ts, sarray[i, :])
+        rsigma_array = np.array([fit_BlackScholesMerton_model(ts, sarray[i, :], unit='day')
                                  for i in range(nbsimulations)])
         average_r = np.nanmean(rsigma_array[:, 0])
         std_r = np.nanstd(rsigma_array[:, 0])
